#!/bin/bash

# Automates the packaging process of the software "pixman" for
# use with Zenwalk Linux.
#	
# Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>

# Summary:	pixel-manipulation library for X and cairo
# Name:		pixman
# License:	MIT
# Group:	System Environment/Libraries
# URL:		http://cairographics.org/
# BuildRequires: xorg-libs >= 7.4
# BuildRequires: pkgconfig
# BuildRequires: xorg-protocols
# Requires:  xorg-libs >= 7.4
# Requires: pkgconfig
# Requires: xorg-protocols

# Source:	http://xorg.freedesktop.org/releases/individual/lib/pixman-0.14.0.tar.bz2



# Variables:
#_______________________________________________________________________



Source_Name="pixman"
Software_Name="${Source_Name}"
Source_Version="0.14.0"
Software_Version="${Source_Version}"
Release="60"
Build="1"

Flag_Arch='i486'
Flag_Tune='i686'
Package_Arch="${Flag_Arch}"

Special_Docs=" "
Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"
	
Build_Root=$(pwd)
Package="${Software_Name}-${Software_Version}-${Package_Arch}-${Release}.${Build}"
Installation_Root="${Build_Root}/${Package}"

Sources=" \
	${Source_Name}-${Source_Version}.tar.bz2"
Patches=" "
Scripts=" \
	build-${Software_Name}.sh"
Miscellaneous=" "	
Build_Root=$(pwd)



# Clean & prep:
#_______________________________________________________________________



# Remove cruft and create Installation_Root
	rm -rf ${Package}* ${Package}-src* 1>/dev/null 2>&1
	mkdir ${Installation_Root}
# Check for necessary files:
	for File in ${Sources} ${Patches} ${Scripts} ${Miscellaneous} ; do
		echo -n "${File} :"
		if [ -e ${File} ]; then
			echo " OK"
		else
			echo " MISSING !"
			exit 1
		fi
	done
# Add a package description file:
mkdir -p ${Installation_Root}/install
cat <<EOF0 > ${Installation_Root}/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
pixman: pixman (pixel-manipulation library for X and cairo)
pixman:
pixman: A library for manipulating pixel regions -- a set of Y-X banded
pixman: rectangles, image compositing using the Porter/Duff model and
pixman: implicit mask generation for geometric primitives including
pixman: trapezoids, triangles, and rectangles.
pixman:
pixman:
pixman:
pixman:
pixman:
EOF0
# Install build-scripts patches and miscellaneous items:
	mkdir -p ${Installation_Root}/usr/src/${Software_Name}-${Software_Version}
	cp ${Patches} ${Scripts} ${Miscellaneous} \
	${Installation_Root}/usr/src/${Software_Name}-${Software_Version}/


# Build:
#_______________________________________________________________________



for File in ${Sources} ; do
	Source_Dir="$(basename ${File} .tar.bz2)"
	rm -rf ${Source_Dir}
	tar jxvf ${File}
	cd ${Source_Dir}
# Ensure proper permissions and ownership:
	chown -R root:root .
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
# Configuration:
	./configure \
	CFLAGS="-O2 -march=${Flag_Arch} -mtune=${Flag_Tune}" \
	CXXFLAGS="${CFLAGS}" \
	PKG_CONFIG_PATH=/usr/lib/pkgconfig \
	--prefix=/usr \
	--bindir=/usr/bin \
	--sbindir=/usr/sbin \
	--libexecdir=/usr/libexec \
	--sysconfdir=/etc \
	--sharedstatedir=/usr/com \
	--localstatedir=/var \
	--libdir=/usr/lib \
	--includedir=/usr/include \
	--oldincludedir=/usr/include \
	--infodir=/usr/info \
	--mandir=/usr/man \
	--silent
# Compilation:
	make --silent || exit 1
	make check || exit 1
# Installation:
	make install --silent  DESTDIR=${Installation_Root} || exit 1
# Documentation:
	mkdir -p ${Installation_Root}/usr/doc/${Source_Dir}/
	for Doc in {${Standard_Docs},${Special_Docs}} ; do
		if [ -e ${Doc} ] ; then
			cp ${Doc} ${Installation_Root}/usr/doc/${Source_Dir}/
		fi
	done
	(
		cd ${Installation_Root}/usr/doc/${Source_Dir}/
		find . -name "*" -size 0c -exec rm {} \;
	)
# Post-build Cleanup:
	cd ${Build_Root}
	rm -rf ${Source_Dir}
done



# Packaging:
#_______________________________________________________________________



# Strip binaries:
	(
		cd ${Installation_Root}
		find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
		find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	)
# Compress the man pages.
	if [ -d ${Installation_Root}/usr/man ]; then
	(
		cd ${Installation_Root}/usr/man
		gzip -9 */*
	)
	fi
# Create dep file:
	(
		cd ${Installation_Root}
		requiredbuilder -z ${Installation_Root} >> ${Build_Root}/${Package}.dep
	)
# Compress the package:
    (
      cd ${Installation_Root}
      makepkg -l y -c n ${Build_Root}/${Package}.tgz
    )
# Calculate the MD5 sum:
    cd ${Build_Root}
      md5sum ${Package}.tgz > ${Package}.md5
# Create a source package and checksum:
	mkdir ${Package}-src
	cp  ${Sources} ${Patches} ${Scripts} ${Miscellaneous} \
		${Package}-src
	tar jcf ${Package}-src.tar.bz2 ${Package}-src
	md5sum ${Package}-src.tar.bz2 > ${Package}-src.md5
# Post-build cleanup:
	rm -rf ${Installation_Root} ${Package}-src



# Changelog:
#_______________________________________________________________________



# ~ Tue Feb 10th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: pixman-0.14.0
# ~ Release: 60
# ~ Build: 1
# ~ Diff: Updated package containing:
# ~ 	pixman-0.14.0

# ~ Mon Feb 2nd 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: pixman-0.13.2
# ~ Release: 60
# ~ Build: 1
# ~ Diff: Initial build containing:
# ~ 	pixman-0.13.2
